@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 import os
-import subprocess
 import sys
-import asyncio
 from hooks.aioproc import aioprocess, async_run
 import colorama
 from colorama import Fore, Style
@@ -58,7 +56,7 @@ def init_dev():
     print(Style.RESET_ALL, Style.DIM)
     try:
         execute(sys.executable, "-m", "pip", "install", "pre-commit")
-        execute("pre-commit", "install")
+        execute("pre-commit", "install", cwd="{{ cookiecutter.project_slug }}")
         print(Style.NORMAL, Fore.GREEN, "pre-commit hooks was successfully installed")
         print(Style.RESET_ALL)
     except Exception as e:
@@ -87,7 +85,7 @@ def init_dev():
     try:
         print(Style.NORMAL, Fore.BLUE, "install all dev dependency packages...")
         print(Style.RESET_ALL, Style.DIM)
-        execute("poetry", "install", "-E", "dev", "-E", "doc", "-E", "test")
+        execute("poetry", "install", "-E", "dev", "-E", "doc", "-E", "test", cwd=PROJECT_DIRECTORY)
         print(
             Style.NORMAL,
             Fore.GREEN,
@@ -104,6 +102,7 @@ def init_dev():
         )
 
 
+
 if __name__ == "__main__":
     colorama.init()
 
